# spectralLib

A python library for analyzing multi and hyper spectral images.
For GUI tool, go to [spectralUI](https://gitlab.com/TomAmpiath/spectralUI)

## Installation
```bash
pip install spectralLib
```

## Usage
See [Documentation](https://gitlab.com/TomAmpiath/spectralLib/Doc/documentation.pdf).